import get from 'lodash/get';
import fs from 'fs';

const isHostAllowed = regexes => host =>
  regexes.reduce(
    (accumulator, currentRe) => accumulator || currentRe.test(host),
    false
  );

const commaDelimit = (config, path) => (get(config, path) || []).join(',')

const mapConfig = config => {
  const regexes = (get(config, 'allow-origin-regexes') || []).map(
    reString => new RegExp(reString)
  );
  return {
    regexes,
    allowMethods: commaDelimit(config, 'allow-methods'),
    allowHeaders: commaDelimit(config, 'allow-headers'),
    exposeHeaders: commaDelimit(config, 'expose-headers'),
    maxAge: get(config, 'max-age'),
    allowCredentials: get(config, 'allow-credentials'),
    isHostAllowed: isHostAllowed(regexes)
  };
};

export const defaultConfig = mapConfig({
  'allow-origin-regexes': ['^http.*$'],
  'allow-methods': ['GET', 'POST', 'PUT'],
  'allow-headers': [
    'Content-Type',
    'X-Amz-Date',
    'Authorization',
    'X-Api-Key',
    'X-Amz-Security-Token'
  ],
  'expose-Headers': [],
  'max-age': 86400,
  'allow-credentials': true
});
